@@ -103,7 +103,7 @@ Args:
   use_absolute_pos: Set `True` to use absolute positional embeddings.
   dynamic_shape: Set `True` for dynamically change output shape depending on inputs shape.
       - Works only if coming inputs shape is smaller than orignal initialized `position_height` and `position_width`.
-      - For larger inputs, please reload layer weights by `self.load_resized_pos_emb`.
+      - For larger inputs, please reload layer weights by `self.load_resized_weights`.
 
 Examples:
 
@@ -125,13 +125,13 @@ aa(tf.ones([1, 4, 14, 16, 32])).shape = TensorShape([1, 4, 14, 16, 14, 16])
 >>> print(f"{aa(tf.ones([1, 4, 4, 6, 32])).shape = }")  # last 2 dimension in output is `[height, width]`
 aa(tf.ones([1, 4, 4, 6, 32])).shape = TensorShape([1, 4, 4, 6, 4, 6])
 
-Reload layer weights by `self.load_resized_pos_emb`:
+Reload layer weights by `self.load_resized_weights`:
 >>> bb = attention_layers.RelativePositionalEmbedding(dynamic_shape=True)
 >>> bb.build([None, 4, 24, 26, 32])
 >>> print({ii.name:ii.shape for ii in bb.weights})
 {'r_height:0': TensorShape([32, 47]),
  'r_width:0': TensorShape([32, 51])}
->>> bb.load_resized_pos_emb(aa)
+>>> bb.load_resized_weights(aa)
 >>> print(f"{bb(tf.ones([1, 4, 21, 22, 32])).shape = }")
 bb(tf.ones([1, 4, 21, 22, 32])).shape = TensorShape([1, 4, 21, 22, 21, 22])
 """
