@@ -227,9 +227,11 @@ class RandomProcessImageWithBboxes:
         if magnitude > 0:
             from keras_cv_attention_models.imagenet import augment
 
-            if color_augment_method.lower() == "autoaug":
+            if color_augment_method is None:
+                self.randaug_wo_pos = lambda image: image
+            elif isinstance(color_augment_method, str) and color_augment_method.lower() == "autoaug":
                 self.randaug_wo_pos = augment.AutoAugment(augmentation_name="simple")
-            elif color_augment_method.lower() == "randaug":
+            elif isinstance(color_augment_method, str) and color_augment_method.lower() == "randaug":
                 # TODO: Need to pick color related methods, "Invert" / "Posterize" may not working well here.
                 print(">>>> RandAugment: magnitude = %d" % magnitude)
                 self.randaug_wo_pos = augment.RandAugment(
@@ -240,8 +242,11 @@ class RandomProcessImageWithBboxes:
                     use_positional_related_ops=False,  # Set False to exlude [shear, rotate, translate]
                     **randaug_kwargs,
                 )
-            else:
+            elif isinstance(color_augment_method, str):
                 self.randaug_wo_pos = random_hsv
+            else:
+                print(">>>> Using user defined color_augment_method: {}".format(getattr(color_augment_method, "__name__", color_augment_method)))
+                self.randaug_wo_pos = color_augment_method
 
             # RandAugment positional related ops. Including [shear, rotate, translate], Also returns affine transform matrix
             # self.pos_randaug = augment.PositionalRandAugment(num_layers=num_layers, magnitude=magnitude, **randaug_kwargs)
@@ -399,12 +404,14 @@ def init_dataset(
     anchors_mode="efficientdet",
     anchor_pyramid_levels=[3, 7],
     anchor_scale=4,  # For efficientdet anchors only
+    aspect_ratios=(1, 2, 0.5),  # For efficientdet anchors only
+    num_scales=3,  # For efficientdet anchors only
     rescale_mode="torch",  # rescale mode, ["tf", "torch"], or specific `(mean, std)` like `(128.0, 128.0)`
     random_crop_mode=1.0,  # 0 for eval mode, (0, 1) for random crop, 1 for random largest crop, > 1 for random scale
     mosaic_mix_prob=0.0,
     resize_method="bilinear",  # ["bilinear", "bicubic"]
     resize_antialias=False,
-    color_augment_method="random_hsv",  # one of ["random_hsv", "autoaug", "randaug"]
+    color_augment_method="random_hsv",  # one of ["random_hsv", "autoaug", "randaug"], or totally custom one like `lambda image: image`
     positional_augment_methods="rts",  # Positional augment method besides scale, combine of r: rotate, t: transplate, s: shear
     magnitude=0,
     num_layers=2,
@@ -448,7 +455,7 @@ def init_dataset(
         train_dataset = train_dataset.map(mosaic_mix, num_parallel_calls=AUTOTUNE)
     # return train_dataset
 
-    if magnitude > 0:
+    if magnitude > 0 and positional_augment_methods is not None and len(positional_augment_methods) != 0:
         # Apply randaug rotate / shear / transform after mosaic mix
         max_labels_per_image = (max_labels_per_image * 4) if mosaic_mix_prob > 0 else max_labels_per_image
         pos_aug = PositionalRandAugmentWithBboxes(magnitude, num_layers, max_labels_per_image, positional_augment_methods, **augment_kwargs)
@@ -465,7 +472,7 @@ def init_dataset(
         bbox_process = lambda bb: __yolor_bboxes_labels_batch_func__(bb[0], bb[1], anchor_ratios, feature_sizes, empty_label, num_classes)
     else:
         # grid_zero_start = True if anchor_grid_zero_start == "auto" else anchor_grid_zero_start
-        aspect_ratios, num_scales, grid_zero_start = [1, 2, 0.5], 3, False  # Use this till meet some others new
+        grid_zero_start = False  # Use this till meet some others new
         anchors = anchors_func.get_anchors(input_shape[:2], anchor_pyramid_levels, aspect_ratios, num_scales, anchor_scale, grid_zero_start)
         num_anchors = anchors.shape[0]
         empty_label = tf.zeros([num_anchors, 4 + num_classes + 1])  # All 0
@@ -502,12 +509,16 @@ def draw_bboxes(bboxes, ax=None):
     return ax
 
 
-def show_image_with_bboxes(image, bboxes, labels=None, confidences=None, is_bbox_width_first=False, ax=None, label_font_size=8, num_classes=80):
+def show_image_with_bboxes(
+    image, bboxes, labels=None, confidences=None, is_bbox_width_first=False, ax=None, label_font_size=8, num_classes=80, indices_2_labels=None
+):
     import matplotlib.pyplot as plt
     import numpy as np
 
+    need_plt_show = False
     if ax is None:
         fig, ax = plt.subplots()
+        need_plt_show = True
     ax.imshow(image)
     bboxes = np.array(bboxes)
     if is_bbox_width_first:
@@ -520,7 +531,9 @@ def show_image_with_bboxes(image, bboxes, labels=None, confidences=None, is_bbox
 
         if labels is not None:
             label = int(labels[id])
-            if num_classes == 90:
+            if indices_2_labels is not None:
+                label = indices_2_labels.get(label, indices_2_labels.get(str(label), "None"))
+            elif num_classes == 90:
                 label = COCO_90_LABEL_DICT[label]
             elif num_classes == 80:
                 label = COCO_80_LABEL_DICT[label]
@@ -532,11 +545,14 @@ def show_image_with_bboxes(image, bboxes, labels=None, confidences=None, is_bbox
             ax.text(bb[1], bb[0] - 5, label, color=color, fontsize=label_font_size)
     ax.set_axis_off()
     plt.tight_layout()
-    plt.show()
+    if need_plt_show:
+        plt.show()
     return ax
 
 
-def show_batch_sample(dataset, rescale_mode="torch", rows=-1, label_font_size=8, base_size=3, anchors_mode="efficientdet", **anchor_kwargs):
+def show_batch_sample(
+    dataset, rescale_mode="torch", rows=-1, label_font_size=8, base_size=3, anchors_mode="efficientdet", indices_2_labels=None, **anchor_kwargs
+):
     import matplotlib.pyplot as plt
     from keras_cv_attention_models.visualizing import get_plot_cols_rows
 
@@ -576,7 +592,7 @@ def show_batch_sample(dataset, rescale_mode="torch", rows=-1, label_font_size=8,
         elif not anchors_mode == anchors_func.ANCHOR_FREE_MODE:
             valid_anchors = anchors[pick]
             valid_preds = anchors_func.decode_bboxes(valid_preds, valid_anchors)
-        show_image_with_bboxes(image, valid_preds[:, :4], valid_preds[:, -1], ax=ax, label_font_size=label_font_size)
+        show_image_with_bboxes(image, valid_preds[:, :4], valid_preds[:, -1], ax=ax, label_font_size=label_font_size, indices_2_labels=indices_2_labels)
     fig.tight_layout()
     plt.show()
     return fig
