@@ -1,7 +1,9 @@
 import os
+import json
+import numpy as np
+import tensorflow as tf
 from keras_cv_attention_models.imagenet import data
 from keras_cv_attention_models.model_surgery import change_model_input_shape
-import tensorflow as tf
 
 
 class TorchModelInterf:
@@ -67,12 +69,37 @@ class TFLiteModelInterf:
         return tf.concat(preds, 0).numpy()
 
 
+class ONNXModelInterf:
+    def __init__(self, model_file):
+        import onnx
+        import onnxruntime as ort
+
+        ort.set_default_logger_severity(3)
+        model_content = onnx.load_model(model_file)
+        model_content.graph.input[0].type.tensor_type.shape.dim[0].dim_param = "None"  # Set batch_size as dynamic
+        model_content.graph.output[0].type.tensor_type.shape.dim[0].dim_param = "None"  # Set batch_size as dynamic
+
+        self.ort_session = ort.InferenceSession(model_content.SerializeToString())
+        self.input_name = self.ort_session.get_inputs()[0].name
+        self.output_names = [self.ort_session.get_outputs()[0].name]
+        self.input_shape = self.ort_session.get_inputs()[0].shape
+        self.output_shape = self.ort_session.get_outputs()[0].shape
+
+        # Regard channel shape as the smallest value, and if it's on dimension 1, regard as channel first NCHW format
+        self.data_format = "NCHW" if min(self.input_shape[1:]) == self.input_shape[1] else "NHWC"
+
+    def __call__(self, imgs):
+        imgs = imgs.numpy() if hasattr(imgs, "numpy") else imgs
+        if self.data_format == "NCHW":
+            imgs = imgs.transpose(0, 3, 1, 2)
+        return self.ort_session.run(self.output_names, {self.input_name: imgs.astype("float32")})[0]
+
+
 def evaluation(
     model, data_name="imagenet2012", input_shape=None, batch_size=64, central_crop=1.0, resize_method="bicubic", antialias=True, rescale_mode="auto"
 ):
-    from tqdm import tqdm
-    import numpy as np
     import types
+    from tqdm import tqdm
 
     if isinstance(model, tf.keras.models.Model):
         input_shape = model.input_shape[1:-1] if input_shape is None else input_shape[:2]
@@ -84,6 +111,10 @@ def evaluation(
         print(">>>> Using input_shape {} for TFLite model.".format(input_shape))
     elif isinstance(model, types.LambdaType):
         model_interf = model
+    elif isinstance(model, str) and model.endswith(".onnx"):
+        model_interf = ONNXModelInterf(model)
+        input_shape = model_interf.input_shape[2:] if model_interf.data_format == "NCHW" else model_interf.input_shape[1:-1]
+        print(">>>> Using input_shape {} for ONNX model, data_format: {}.".format(input_shape, model_interf.data_format))
     else:
         model_interf = TorchModelInterf(model)
         assert input_shape is not None
@@ -116,6 +147,23 @@ def evaluation(
     return y_true, y_pred_top_1, y_pred_top_5
 
 
+def decode_predictions_imagenet21k(preds, top=5):
+    """Similar function from keras.applications.imagenet_utils.decode_predictions, just using imagenet21k class index"""
+    if len(preds.shape) != 2 or preds.shape[1] != 1000:
+        pass
+    url = "https://github.com/leondgarse/keras_cv_attention_models/releases/download/efficientdet/imagenet21k_class_index.json"
+    class_index_path = tf.keras.utils.get_file(origin=url)
+    with open(class_index_path) as ff:
+        class_index = json.load(ff)
+    results = []
+    for pred in preds:
+        top_indices = pred.argsort()[-top:][::-1]
+        result = [tuple(class_index[str(i)]) + (pred[i],) for i in top_indices]
+        result.sort(key=lambda x: x[2], reverse=True)
+        results.append(result)
+    return results
+
+
 def parse_timm_log(log_file, pick_keys=None):
     with open(log_file, "r") as ff:
         aa = ff.readlines()
@@ -155,8 +203,6 @@ def parse_timm_log(log_file, pick_keys=None):
 
 
 def combine_hist_into_one(hist_list, save_file=None):
-    import json
-
     hh = {}
     for hist in hist_list:
         with open(hist, "r") as ff:
@@ -172,7 +218,6 @@ def combine_hist_into_one(hist_list, save_file=None):
 
 def curve_fit(source, target_len=10, skip=5, use_recent=40):
     from scipy.optimize import curve_fit
-    import numpy as np
 
     def func_curv(x, a, b, c, d):
         pp = np.log(x)
@@ -208,9 +253,6 @@ def plot_and_peak_scatter(ax, source_array, peak_method, label, skip_first=0, co
 
 
 def plot_hists(hists, names=None, base_size=6, addition_plots=["lr"], text_va=["bottom"], skip_first=0, pred_curve=0):
-    import os
-    import json
-    import numpy as np
     import matplotlib as mpl
     import matplotlib.pyplot as plt
 
