@@ -89,6 +89,8 @@ def mhsa_mlp_block(
 ):
     attn = group_norm(inputs, groups=num_norm_groups, name=name + "attn_") if num_norm_groups > 0 else layer_norm(inputs, name=name + "attn_")
     if use_linear_attention:  # V2
+        if num_norm_groups > 0:
+            attn = keras.layers.Reshape(attn.shape[1:])(attn)  # Or will throw error when converting tflite, if GroupNorm is followed by Conv2D
         attn = linear_self_attention(attn, qkv_bias=qkv_bias, out_bias=True, attn_dropout=attn_drop_rate, name=name and name + "attn_mhsa_")
     else:  # V1
         attn = multi_head_self_attention(attn, num_heads, qkv_bias=qkv_bias, out_bias=True, attn_dropout=attn_drop_rate, name=name and name + "attn_mhsa_")
@@ -97,10 +99,12 @@ def mhsa_mlp_block(
     attn_out = keras.layers.Add(name=name and name + "attn_out")([inputs, attn])
 
     mlp = group_norm(attn_out, groups=num_norm_groups, name=name + "mlp_") if num_norm_groups > 0 else layer_norm(attn_out, name=name + "mlp_")
+    if use_conv_mlp and num_norm_groups > 0:  # V2
+        mlp = keras.layers.Reshape(mlp.shape[1:])(mlp)  # Or will throw error when converting tflite, if GroupNorm is followed by Conv2D
     mlp = mlp_block(mlp, int(out_channel * mlp_ratio), drop_rate=mlp_drop_rate, use_conv=use_conv_mlp, activation=activation, name=name and name + "mlp_")
     mlp = ChannelAffine(use_bias=False, weight_init_value=layer_scale, name=name and name + "2_gamma")(mlp) if layer_scale >= 0 else mlp
     mlp = drop_block(mlp, drop_rate=drop_rate, name=name and name + "mlp_")
-    return keras.layers.Add(name=name and name + "output")([attn_out, mlp])
+    return keras.layers.Add(name=name and name + "out")([attn_out, mlp])
 
 
 def transformer_pre_process(inputs, out_channel, patch_size=2, resize_first=False, use_depthwise=False, patches_to_batch=True, activation="swish", name=""):
@@ -162,7 +166,7 @@ def transformer_post_process(inputs, pre_attn, out_channel, patch_size=2, patch_
         nn = tf.concat([pre_attn, nn], axis=-1)
         nn = conv2d_no_bias(nn, out_channel, kernel_size=3, strides=1, padding="SAME", name=name + "post_2_")
         nn = batchnorm_with_activation(nn, activation=activation, name=name + "post_2_")
-    return nn
+    return keras.layers.Activation("linear", name=name + "output")(nn)  # Identity, Just need a name here
 
 
 def MobileViT(
