@@ -231,7 +231,7 @@ def YOLOX(
         if isinstance(features_pick[0], str):
             features = [backbone.get_layer(layer_name) for layer_name in features_pick]
         else:
-            features = model_surgery.get_pyramide_feture_layers(backbone)
+            features = model_surgery.get_pyramide_feature_layers(backbone)
             features = [features[id] for id in features_pick]
         print(">>>> features:", {ii.name: ii.output_shape for ii in features})
         features = [ii.output for ii in features]
